@@ -441,8 +441,15 @@ struct arma_rng::randn< std::complex<T> >
   inline
   operator std::complex<T> () const
     {
-    T a(0);
-    T b(0);
+    #if defined(_MSC_VER)
+      // attempt at workaround for MSVC bug
+      // does MS even test their so-called compilers before release?
+      T a;
+      T b;
+    #else
+      T a(0);
+      T b(0);
+    #endif
     
     arma_rng::randn<T>::dual_val(a, b);
     
