@@ -87,6 +87,12 @@
 // #define ARMA_USE_MKL_ALLOC
 //// Uncomment the above line if you want to use Intel MKL mkl_malloc() and mkl_free() instead of standard malloc() and free()
 
+// #define ARMA_USE_MKL_TYPES
+//// Uncomment the above line if you want to use Intel MKL types for complex numbers.
+//// You will need to include appropriate MKL headers before the Armadillo header.
+//// You may also need to enable or disable the following options:
+//// ARMA_BLAS_LONG, ARMA_BLAS_LONG_LONG, ARMA_USE_FORTRAN_HIDDEN_ARGS
+
 /* #undef ARMA_USE_ATLAS */
 #define ARMA_ATLAS_INCLUDE_DIR /
 //// If you're using ATLAS and the compiler can't find cblas.h and/or clapack.h
@@ -250,7 +256,7 @@
 #if defined(ARMA_USE_WRAPPER)
   #if defined(ARMA_USE_CXX11)
     #if !defined(ARMA_USE_EXTERN_CXX11_RNG)
-/* #undef ARMA_USE_EXTERN_CXX11_RNG */
+      #define ARMA_USE_EXTERN_CXX11_RNG
     #endif
   #endif
 #endif
@@ -289,5 +295,5 @@
 // ARMA_AUX_LIBS lists the libraries required by Armadillo on this system, and
 // ARMA_AUX_INCDIRS lists the include directories required by Armadillo on this system.
 // Do not use these unless you know what you are doing.
-#define ARMA_AUX_LIBS /usr/local/lib/libblas.so.2.1;gfortran;/usr/local/lib/liblapack.so.7.1;gfortran;/usr/local/lib/libhdf5.so.2.0;/usr/lib/libz.so.5.0;/usr/lib/libm.so.10.1;/usr/local/lib/libarpack.so.1.0
+#define ARMA_AUX_LIBS /usr/local/lib/libblas.so.2.1;gfortran;/usr/local/lib/liblapack.so.7.1;gfortran;/usr/local/lib/libhdf5.so.2.1;/usr/lib/libz.so.5.0;/usr/lib/libm.so.10.1;/usr/local/lib/libarpack.so.1.0
 #define ARMA_AUX_INCDIRS /usr/local/include
